rm(list=ls())
library(ape)
library(geiger)
library(phytools)

#Load in tree
afro_tree <- read.nexus("USER/PATH/Nuc_16S_pruned_con.tre")
plot(afro_tree, cex = 0.5)

#Load in data
afro_data <- read.csv("USER/PATH/Traits.csv")

#make data frame
afro <- data.frame(afro_data[,2:5])
rownames(afro) <- afro_data[,1]
attach(afro)

#Assign rownames
#adult_ecology  oviposition  water_code	repro_mode
names(adult_ecology) <- rownames(afro)
names(oviposition) <- rownames(afro)
names(water_code) <- rownames(afro)
names(repro_mode) <- rownames(afro)

#Matching between data and tips
namecheck_out <- name.check(afro_tree, afro)
namecheck_out
length(namecheck_out$tree_not_data)

drop.tip(afro_tree, namecheck_out$tree_not_data) -> afro_analysis_tree
plot(afro_analysis_tree, cex=0.5)

##########################################################################################
#Make q-matrices for simulations of each character for ER
#These numbers come from values retrieved by ACE and simmap
#and are specific to my data set.

q_ae <-matrix(c(-0.004, 0.004, 0.004, 
                0.004, -0.004, 0.004, 
                0.004, 0.004, -0.004), 3, 3)
#q_ae <-list(q_ae)

q_os <-matrix(c(-0.004, 0.004, 0.004, 0.004, 
                0.004, -0.004, 0.004, 0.004, 
                0.004, 0.004, -0.004, 0.004,
                0.004, 0.004, 0.004, -0.004), 4, 4)
#q_os <-list(q_os)

q_wc <-matrix(c(-0.004, 0.004,
                0.004, -0.004), 2, 2)
#q_wc <- list(q_wc)

q_rm <-matrix(c(-0.004, 0.004, 0.004, 0.004, 
                0.004, -0.004, 0.004, 0.004, 
                0.004, 0.004, -0.004, 0.004,
                0.004, 0.004, 0.004, -0.004), 4, 4)
#q_rm <- list(q_rm)

#Test out simulations to see if character distributions are reasonable
ae_sims <- sim.history(afro_analysis_tree, q_ae, nsim=1, anc = 1)
ae_sims$states
os_sims <- sim.history(afro_analysis_tree, q_os, nsim=1, anc = 2)
os_sims$states
wc_sims <- sim.history(afro_analysis_tree, q_wc, nsim=1, anc = 1)
wc_sims$states
rm_sims <- sim.history(afro_analysis_tree, q_rm, nsim=1, anc = 3)
rm_sims$states

#Create a matrix of the independent simulations above
sim_list <- list(ae_sims$states, os_sims$states, wc_sims$states, rm_sims$states)
sim_list
sim_matrix <- do.call(rbind, sim_list)
sim_matrix
transpose <- t(sim_matrix)
transpose

#That looks nice, but is only one simulation


##########################################################################################
#Prepare for making 500 output files with independent simulations of
#each character

#Function doing the exact same thing as above, but 500 times, and each time
#an output is 
for (i in 1:500) {
  ae_sims <- sim.history(afro_analysis_tree, q_ae, nsim=1, anc = 1)
  ae_sims$states
  os_sims <- sim.history(afro_analysis_tree, q_os, nsim=1, anc = 2)
  os_sims$states
  wc_sims <- sim.history(afro_analysis_tree, q_wc, nsim=1, anc = 1)
  wc_sims$states
  rm_sims <- sim.history(afro_analysis_tree, q_rm, nsim=1, anc = 3)
  rm_sims$states
  
  sim_list <- list(ae_sims$states, os_sims$states, wc_sims$states, rm_sims$states)
  sim_list
  sim_matrix <- do.call(rbind, sim_list)
  sim_matrix
  transpose <- t(sim_matrix)
  transpose
  
  write.table(transpose, paste("ae",i,".txt", sep="_"), sep="\t", quote=FALSE)
  
}
